#include "xusbpsu.h"

XUsbPsu_Config XUsbPsu_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"snps,dwc3", /* compatible */
		0xf1c00000, /* reg */
		0x1, /* dma-coherent */
		0x0, /* xlnx,enable-superspeed */
		{0x4022,  0x4022,  0x4026}, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	 {
		 NULL
	}
};